==> eam-wshub-proxyclient-11.4-0-sources.jar: net/datastream/schemas/mp_fields/FORMULAPARAMETERID_Type.java <==

package net.datastream.schemas.mp_fields;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlType;


/**
 * <p>Java class for FORMULAPARAMETERID_Type complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType name="FORMULAPARAMETERID_Type">
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}FORMULAID"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}PARAMETERID"/>
 *       &lt;/sequence>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "FORMULAPARAMETERID_Type", propOrder = {
    "formulaid",
    "parameterid"
})
public class FORMULAPARAMETERID_Type {

    @XmlElement(name = "FORMULAID", required = true)
    protected FORMULAID_Type formulaid;
    @XmlElement(name = "PARAMETERID", required = true)
    protected PARAMETERID_Type parameterid;

    /**
     * Gets the value of the formulaid property.
     * 
     * @return
     *     possible object is
     *     {@link FORMULAID_Type }
     *     
     */
    public FORMULAID_Type getFORMULAID() {
        return formulaid;
    }

    /**
     * Sets the value of the formulaid property.
     * 
     * @param value
     *     allowed object is
     *     {@link FORMULAID_Type }
     *     
     */
    public void setFORMULAID(FORMULAID_Type value) {
        this.formulaid = value;
    }

    /**
     * Gets the value of the parameterid property.
     * 
     * @return
     *     possible object is
     *     {@link PARAMETERID_Type }
     *     
     */
    public PARAMETERID_Type getPARAMETERID() {
        return parameterid;
    }

    /**
     * Sets the value of the parameterid property.
     * 
     * @param value
     *     allowed object is
     *     {@link PARAMETERID_Type }
     *     
     */
    public void setPARAMETERID(PARAMETERID_Type value) {
        this.parameterid = value;
    }

}

==> eam-wshub-proxyclient-11.4-10-sources.jar: net/datastream/schemas/mp_fields/FORMULAPARAMETERID_Type.java <==

package net.datastream.schemas.mp_fields;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlType;


/**
 * <p>Classe Java pour FORMULAPARAMETERID_Type complex type.
 * 
 * <p>Le fragment de schéma suivant indique le contenu attendu figurant dans cette classe.
 * 
 * <pre>
 * &lt;complexType name="FORMULAPARAMETERID_Type">
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}FORMULAID"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}PARAMETERID"/>
 *       &lt;/sequence>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "FORMULAPARAMETERID_Type", propOrder = {
    "formulaid",
    "parameterid"
})
public class FORMULAPARAMETERID_Type {

    @XmlElement(name = "FORMULAID", required = true)
    protected FORMULAID_Type formulaid;
    @XmlElement(name = "PARAMETERID", required = true)
    protected PARAMETERID_Type parameterid;

    /**
     * Obtient la valeur de la propriété formulaid.
     * 
     * @return
     *     possible object is
     *     {@link FORMULAID_Type }
     *     
     */
    public FORMULAID_Type getFORMULAID() {
        return formulaid;
    }

    /**
     * Définit la valeur de la propriété formulaid.
     * 
     * @param value
     *     allowed object is
     *     {@link FORMULAID_Type }
     *     
     */
    public void setFORMULAID(FORMULAID_Type value) {
        this.formulaid = value;
    }

    /**
     * Obtient la valeur de la propriété parameterid.
     * 
     * @return
     *     possible object is
     *     {@link PARAMETERID_Type }
     *     
     */
    public PARAMETERID_Type getPARAMETERID() {
        return parameterid;
    }

    /**
     * Définit la valeur de la propriété parameterid.
     * 
     * @param value
     *     allowed object is
     *     {@link PARAMETERID_Type }
     *     
     */
    public void setPARAMETERID(PARAMETERID_Type value) {
        this.parameterid = value;
    }

}
